@@ -1,11 +1,8 @@
 from __future__ import annotations
 
+from typing import Any
 from typing import Callable
 
-import gdb
-
-import pwndbg.gdblib.symbol
-import pwndbg.gdblib.vmmap
 import pwndbg.integration
 from pwndbg.color import ColorConfig
 from pwndbg.color import ColorParamSpec
@@ -32,11 +29,11 @@ def get_address_and_symbol(address: int) -> str:
     Convert and colorize address 0x7ffff7fcecd0 to string `0x7ffff7fcecd0 (_dl_fini)`
     If no symbol exists for the address, return colorized address
     """
-    symbol = pwndbg.gdblib.symbol.get(address) or None
+    symbol = pwndbg.aglib.symbol.resolve_addr(address)
     if symbol:
         symbol = f"{address:#x} ({symbol})"
     else:
-        page = pwndbg.gdblib.vmmap.find(address)
+        page = pwndbg.aglib.vmmap.find(address)
         if page and "[stack" in page.objfile:
             var = pwndbg.integration.provider.get_stack_var_name(address)
             if var:
@@ -55,11 +52,11 @@ def attempt_colorized_symbol(address: int) -> str | None:
     """
     Convert address to colorized symbol (if symbol is there), else None
     """
-    symbol = pwndbg.gdblib.symbol.get(address) or None
+    symbol = pwndbg.aglib.symbol.resolve_addr(address)
     if symbol:
         return get(address, symbol)
     else:
-        page = pwndbg.gdblib.vmmap.find(address)
+        page = pwndbg.aglib.vmmap.find(address)
         if page and "[stack" in page.objfile:
             var = pwndbg.integration.provider.get_stack_var_name(address)
             if var:
@@ -67,17 +64,24 @@ def attempt_colorized_symbol(address: int) -> str | None:
     return None
 
 
-def get(address: int | gdb.Value, text: str | None = None, prefix: str | None = None) -> str:
+# We have to accept `Any` here, as users may pass gdb.Value objects to this
+# function. This is probably more lenient than we'd really like.
+#
+# TODO: Remove the exception for gdb.Value case from `pwndbg.color.memory.get`.
+def get(
+    address: int | pwndbg.dbg_mod.Value | Any, text: str | None = None, prefix: str | None = None
+) -> str:
     """
     Returns a colorized string representing the provided address.
 
     Arguments:
-        address(int | gdb.Value): Address to look up
+        address(int | pwndbg.dbg_mod.Value): Address to look up
         text(str | None): Optional text to use in place of the address in the return value string.
         prefix(str | None): Optional text to set at beginning in the return value string.
     """
     address = int(address)
-    page = pwndbg.gdblib.vmmap.find(address)
+    page = pwndbg.aglib.vmmap.find(address)
+
     color: Callable[[str], str]
 
     if page is None:
